==> haskell-th-reify-many-0.1.8-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-th-reify-many.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-reify-many
version: 0.1.8
id: th-reify-many-0.1.8-DGCao0sZekU2vOuQlCjVQL
key: th-reify-many-0.1.8-DGCao0sZekU2vOuQlCjVQL
license: BSD3
maintainer: Michael Sloan <mgsloan at gmail>
stability: Experimental
homepage: http://github.com/mgsloan/th-reify-many
synopsis: Recurseively reify template haskell datatype info
description:
    @th-reify-many@ provides functions for recursively reifying top
    level declarations.  The main intended use case is for enumerating
    the names of datatypes reachable from an initial datatype, and
    passing these names to some function which generates instances.
category: Template Haskell
author: Michael Sloan
exposed: True
indefinite: False
exposed-modules:
    Language.Haskell.TH.ReifyMany
    Language.Haskell.TH.ReifyMany.Internal
abi: 903f9683070acbf475698545a9cf284d
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/th-reify-many-0.1.8
library-dirs: /usr/lib/ghc-8.2.2/site-local/th-reify-many-0.1.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/th-reify-many-0.1.8
hs-libraries: HSth-reify-many-0.1.8-DGCao0sZekU2vOuQlCjVQL
depends:
    base-4.10.1.0 containers-0.5.10.2 mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
    safe-0.3.15-EroU33EYnr02fGSZYGiX97 template-haskell-2.12.0.0
    th-expand-syns-0.4.3.0-VxrlkjIeMXK2b9BrI2cQH
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=1e76d6f7019a4b5c8c222b2fbbb06681
             safe-0.3.15-EroU33EYnr02fGSZYGiX97=c20d058560be9a4b5e941a33ed437bf5
             template-haskell-2.12.0.0=2257617827b0258ca46e933b344007b7
             th-expand-syns-0.4.3.0-VxrlkjIeMXK2b9BrI2cQH=54bc5d9b4f7af0bdc415792d6e3d2679
haddock-interfaces: /usr/share/doc/haskell-th-reify-many/html/th-reify-many.haddock
haddock-html: /usr/share/doc/haskell-th-reify-many/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-reify-many-0.1.8-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-th-reify-many.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-reify-many
version: 0.1.8
id: th-reify-many-0.1.8-5GXK75rgh5BpNIIzzPuB7
key: th-reify-many-0.1.8-5GXK75rgh5BpNIIzzPuB7
license: BSD3
maintainer: Michael Sloan <mgsloan at gmail>
stability: Experimental
homepage: http://github.com/mgsloan/th-reify-many
synopsis: Recurseively reify template haskell datatype info
description:
    @th-reify-many@ provides functions for recursively reifying top
    level declarations.  The main intended use case is for enumerating
    the names of datatypes reachable from an initial datatype, and
    passing these names to some function which generates instances.
category: Template Haskell
author: Michael Sloan
exposed: True
indefinite: False
exposed-modules:
    Language.Haskell.TH.ReifyMany
    Language.Haskell.TH.ReifyMany.Internal
abi: 6f52a4934b5a12c31ba14b8748daed80
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/th-reify-many-0.1.8
library-dirs: /usr/lib/ghc-8.2.2/site-local/th-reify-many-0.1.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/th-reify-many-0.1.8
hs-libraries: HSth-reify-many-0.1.8-5GXK75rgh5BpNIIzzPuB7
depends:
    base-4.10.1.0 containers-0.5.10.2 mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
    safe-0.3.15-EroU33EYnr02fGSZYGiX97 template-haskell-2.12.0.0
    th-expand-syns-0.4.4.0-3kFGYL0IHLbFlT4ybVKmjP
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=1e76d6f7019a4b5c8c222b2fbbb06681
             safe-0.3.15-EroU33EYnr02fGSZYGiX97=c20d058560be9a4b5e941a33ed437bf5
             template-haskell-2.12.0.0=2257617827b0258ca46e933b344007b7
             th-expand-syns-0.4.4.0-3kFGYL0IHLbFlT4ybVKmjP=7a15f3b84a2c4ba36cfd7d9b228f9a40
haddock-interfaces: /usr/share/doc/haskell-th-reify-many/html/th-reify-many.haddock
haddock-html: /usr/share/doc/haskell-th-reify-many/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
